@@ -161,19 +161,21 @@ FDistribution <- R6Class("FDistribution",
     #' @param ... Unused.
     pgf = function(z, ...) {
       return(NaN)
-    },
+    }
+  ),
 
-    # optional setParameterValue
-    #' @description
-    #' Sets the value(s) of the given parameter(s).
-    setParameterValue = function(..., lst = NULL, error = "warn", resolveConflicts = FALSE) {
-      super$setParameterValue(..., lst = lst, error = error, resolveConflicts = resolveConflicts)
-      if (self$getParameterValue("df1") == 1) {
-        private$.properties$support <- PosReals$new(zero = FALSE)
+  active = list(
+    #' @field properties
+    #' Returns distribution properties, including skewness type and symmetry.
+    properties = function() {
+      prop <- super$properties
+      prop$support <- if (self$getParameterValue("df1") == 1) {
+        prop$support <- PosReals$new(zero = FALSE)
       } else {
-        private$.properties$support <- PosReals$new(zero = TRUE)
+        prop$support <- PosReals$new(zero = TRUE)
       }
-      invisible(self)
+
+      prop
     }
   ),
 
